## Matbench property models


We have uploaded the property models from fitting the matbench datasets to [https://figshare.com/articles/software/m3gnet_property_model_weights/20099465](https://figshare.com/articles/software/m3gnet_property_model_weights/20099465).
The model can be directly importable with the current framework.
